'Verifying Output Multipliers with the Leontief Price Model - by David Kay

'ReadMe: The Leontief Price Model provides a convenient way to verify the accounting accuracy of IxI input-output tables and corresponding output multipliers derived from underlying make and use tables. The following EViews script provides a step-by-step example of how this can be accomplished programmatically using I-O SNAPs national use and make tables.

'1. Imports I-O SNAP use (u), make (v), industry output (g), commodity output (q), comodity final demand (e), value-added (va), & commodity import (import) tables from Excel to unstructured EViews workfile as matrix objects. Note: user to update local filepath as required.
wfcreate IO u 69
importmat(name=u) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Use.xlsx" range="National Use!b2:bp70"
importmat(name=g) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Use.xlsx" range="National Use!b74:bp74"
importmat(name=e) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Use.xlsx" range="National Use!bq2:bz70"
importmat(name=va) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Use.xlsx" range="National Use!b71:bp73"
importmat(name=v) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Make.xlsx" range="National Make!b2:br68"
importmat(name=q) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Make.xlsx" range="National Make!b70:br70"
importmat(name=import) "C:\Users\daved\OneDrive\Desktop\I-O SNAP\US 2021 National Make.xlsx" range="National Make!b69:br69"

'2. Create row vector, diagonal matrix, and inverse matrix of industry output (g)
vector g_row = g
matrix g_diag = @makediagonal (g_row)
matrix g_inv = @inverse (g_diag)

'3. Create row vector, diagonal matrix, and inverse matrix of commodity output (q)
vector q_row = q
matrix q_diag = @makediagonal (q_row)
matrix q_inv = @inverse (q_diag)

'4. Calculate direct commodity requirments matrix (b)
matrix b = u*g_inv

'5. Calculate market share matrix (_d)
matrix _d = v*q_inv

'6. Calculate direct industry requirments matrix (a)
matrix a = _d*b

'7. Create IxI identity matrix based on number of industries in dataset (identity)
matrix identity = @identity(67)

'8. Calculate IxI multipler matrix (m)
matrix m = @inverse(identity - a)

'9. Calculate commdoity import share row (import_c)
vector import_c = import*q_inv

'10. Calculate industry import share row (import_i)
vector import_i = import_c*b

'11. Create 1x3 summation vector based on number of value-added accounts (sum)
rowvector(3) sum = 1

'12. Sum value-added accounts into single row vector (va_row)
vector va_row = sum*va

'13. Calculate value-added shares (va_coef)
vector va_coef = va_row*g_inv

'14. Calculate total value-added coefficients, including industry import shares (l)
vector l = va_coef+import_i

'15. Calculate Leontief Price Model (i). If all production costs are accounted for in the IxI multiplier framework then this calculation should produce a 1x67 unity row vector containing only 1's.
vector i = l*m

statusline program completed


